sqlmesh.core.model API documentation

Edit on GitHub

# sqlmesh.core.model

View Source

     1from sqlmesh.core.model.common import parse_model_name
     2from sqlmesh.core.model.decorator import model
     3from sqlmesh.core.model.definition import (
     4    Model,
     5    PythonModel,
     6    SeedModel,
     7    SqlModel,
     8    create_python_model,
     9    create_seed_model,
    10    create_sql_model,
    11    load_model,
    12)
    13from sqlmesh.core.model.kind import (
    14    IncrementalByTimeRangeKind,
    15    IncrementalByUniqueKeyKind,
    16    ModelKind,
    17    ModelKindName,
    18    SeedKind,
    19    TimeColumn,
    20)
    21from sqlmesh.core.model.meta import ModelMeta